@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,12 +32,13 @@
 package org.hsqldb;
 
 import org.hsqldb.HsqlNameManager.HsqlName;
-import org.hsqldb.RangeVariable.RangeIteratorBase;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.lib.ArrayUtil;
+import org.hsqldb.lib.HsqlList;
 import org.hsqldb.lib.OrderedHashSet;
+import org.hsqldb.navigator.RangeIterator;
 import org.hsqldb.navigator.RowIterator;
 import org.hsqldb.persist.PersistentStore;
 import org.hsqldb.result.Result;
@@ -49,7 +50,7 @@ import org.hsqldb.types.Type;
  * by the constraint.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.3.5
  * @since 1.6.0
  */
 public final class Constraint implements SchemaObject {
@@ -470,7 +471,7 @@ public final class Constraint implements SchemaObject {
     /**
      *  Returns the main index
      */
-    Index getMainIndex() {
+    public Index getMainIndex() {
         return core.mainIndex;
     }
 
@@ -484,7 +485,7 @@ public final class Constraint implements SchemaObject {
     /**
      *  Returns the reference index
      */
-    Index getRefIndex() {
+    public Index getRefIndex() {
         return core.refIndex;
     }
 
@@ -726,8 +727,8 @@ public final class Constraint implements SchemaObject {
             core.mainTable = newTable;
 
             if (core.mainIndex != null) {
-                core.mainIndex =
-                    core.mainTable.getIndex(core.mainIndex.getName().name);
+                core.mainIndex = core.mainTable.getSystemIndex(
+                    core.mainIndex.getName().name);
                 core.mainCols = ArrayUtil.toAdjustedColumnArray(core.mainCols,
                         colIndex, adjust);
             }
@@ -738,7 +739,7 @@ public final class Constraint implements SchemaObject {
 
             if (core.refIndex != null) {
                 core.refIndex =
-                    core.refTable.getIndex(core.refIndex.getName().name);
+                    core.refTable.getSystemIndex(core.refIndex.getName().name);
                 core.refCols = ArrayUtil.toAdjustedColumnArray(core.refCols,
                         colIndex, adjust);
             }
@@ -797,15 +798,13 @@ public final class Constraint implements SchemaObject {
      */
     void checkCheckConstraint(Session session, Table table, Object[] data) {
 
-        RangeIteratorBase it =
+        RangeIterator it =
             session.sessionContext.getCheckIterator(rangeVariable);
 
         it.setCurrent(data);
 
         boolean nomatch = Boolean.FALSE.equals(check.getValue(session));
 
-        it.setCurrent(null);
-
         if (nomatch) {
             String[] info = new String[] {
                 name.name, table.getName().name
@@ -939,14 +938,8 @@ public final class Constraint implements SchemaObject {
 
         RowIterator it = table.rowIterator(session);
 
-        while (true) {
-            Row row = it.getNextRow();
-
-            if (row == null) {
-                break;
-            }
-
-            Object[] rowData = row.getData();
+        while (it.next()) {
+            Object[] rowData = it.getCurrent();
 
             checkInsert(session, table, rowData, false);
         }
@@ -1000,17 +993,13 @@ public final class Constraint implements SchemaObject {
         // to ensure no subselects etc. are in condition
         check.checkValidCheckConstraint();
 
-        if (table == null) {
-            check.resolveTypes(session, null);
-        } else {
-            QuerySpecification checkSelect = Expression.getCheckSelect(session,
-                table, check);
+        QuerySpecification checkSelect = Expression.getCheckSelect(session,
+            table, check);
 
-            rangeVariable = checkSelect.rangeVariables[0];
+        rangeVariable = checkSelect.rangeVariables[0];
 
-            // removes reference to the Index object in range variable
-            rangeVariable.setForCheckConstraint();
-        }
+        // removes reference to the Index object in range variable
+        rangeVariable.setForCheckConstraint();
 
         if (check.getType() == OpTypes.NOT
                 && check.getLeftNode().getType() == OpTypes.IS_NULL
@@ -1022,6 +1011,23 @@ public final class Constraint implements SchemaObject {
         }
     }
 
+    void prepareDomainCheckConstraint(Session session) {
+
+        // to ensure no subselects etc. are in condition
+        check.checkValidCheckConstraint();
+
+        HsqlList list = check.resolveColumnReferences(session,
+            RangeGroup.emptyGroup, 0, RangeGroup.emptyArray, null, false);
+
+        if (list != null) {
+            Expression e = ((Expression) list.get(0));
+
+            throw Error.error(ErrorCode.X_42501, e.getSQL());
+        }
+
+        check.resolveTypes(session, null);
+    }
+
     void checkCheckConstraint(Session session, Table table) {
 
         if (table.getRowStore(session).elementCount() > 0) {
