@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -61,7 +61,7 @@ import org.hsqldb.types.Collation;
  * It holds the data structures that form an HSQLDB database instance.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class Database {
@@ -389,6 +389,10 @@ public class Database {
     synchronized Session connect(String username, String password,
                                  String zoneString, int timeZoneSeconds) {
 
+        if (getState() != DATABASE_ONLINE) {
+            throw Error.error(ErrorCode.X_08001);
+        }
+
         if (username.equalsIgnoreCase("SA")) {
             username = "SA";
         }
@@ -656,6 +660,8 @@ public class Database {
             if (result && closemode == CLOSEMODE_COMPACT) {
                 clearStructures();
                 reopen();
+                txManager.setGlobalChangeTimestamp(
+                    txManager.getGlobalChangeTimestamp() + 1);
                 setState(DATABASE_CLOSING);
                 sessionManager.closeAllSessions();
                 logger.close(CLOSEMODE_NORMAL);
@@ -776,7 +782,7 @@ public class Database {
 
         r.addRows(list);
 
-        list = getGranteeManager().getSQL();
+        list = granteeManager.getSQL();
 
         r.addRows(list);
 
@@ -786,7 +792,7 @@ public class Database {
         r.addRows(list);
 
         // optional comments on tables etc.
-        list = schemaManager.getCommentsArray();
+        list = schemaManager.getCommentsSQL();
 
         r.addRows(list);
 
@@ -807,17 +813,17 @@ public class Database {
         r.addRows(list);
 
         // password complexity
-        list = getUserManager().getAuthenticationSQL();
+        list = userManager.getAuthenticationSQL();
 
         r.addRows(list);
 
         // user session start schema names
-        list = getUserManager().getInitialSchemaSQL();
+        list = userManager.getInitialSchemaSQL();
 
         r.addRows(list);
 
         // grantee rights
-        list = getGranteeManager().getRightsSQL();
+        list = granteeManager.getRightsSQL();
 
         r.addRows(list);
 
