@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -61,7 +61,7 @@ import org.hsqldb.types.Types;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class Expression implements Cloneable {
@@ -1205,19 +1205,24 @@ public class Expression implements Cloneable {
                                                          nodes[i].dataType);
                 }
 
+                if (nodeDataType != null) {
+                    for (int i = 0; i < nodes.length; i++) {
+                        if (nodes[i].dataType == null) {
+                            nodes[i].valueData =
+                                nodeDataType.convertToDefaultType(
+                                    session, nodes[i].valueData);
+                        } else {
+                            nodes[i].valueData =
+                                nodeDataType.convertToType(
+                                    session, nodes[i].valueData, nodes[i].dataType);
+                        }
+                    }
+                }
+
                 for (int i = 0; i < nodes.length; i++) {
                     nodes[i].dataType = nodeDataType;
                 }
 
-                if (nodeDataType != null) {
-                    for (int i = 0; i < nodes.length; i++) {
-                        if (nodes[i].valueData != null) {
-                            nodes[i].valueData =
-                                nodeDataType.convertToDefaultType(
-                                    session, nodes[i].valueData);
-                        }
-                    }
-                }
 
                 dataType = new ArrayType(nodeDataType, nodes.length);
 
@@ -2118,11 +2123,13 @@ public class Expression implements Cloneable {
         throw Error.runtimeError(ErrorCode.U_S0500, "Expression");
     }
 
-    public Object updateAggregatingValue(Session session, Object currValue) {
+    public SetFunction updateAggregatingValue(Session session,
+            SetFunction currValue) {
         throw Error.runtimeError(ErrorCode.U_S0500, "Expression");
     }
 
-    public Object getAggregatedValue(Session session, Object currValue) {
+    public Object getAggregatedValue(Session session,
+                                     SetFunction currValue) {
         throw Error.runtimeError(ErrorCode.U_S0500, "Expression");
     }
 
