@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,9 +47,9 @@ import org.hsqldb.types.Types;
 /**
  * Implementation of CAST, CASE, LIMIT and ZONE operations.
  *
- * @author Campbell Burnet (boucherb@users dot sourceforge.net)
+ * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.3.5
  * @since 1.9.0
  */
 public class ExpressionOp extends Expression {
@@ -121,6 +121,20 @@ public class ExpressionOp extends Expression {
         this.alias    = e.alias;
     }
 
+    /**
+     * creates a CONVERT expression with format
+     * when format is null, it is a simple CAST
+     */
+    ExpressionOp(Expression e, Type dataType, Expression format) {
+
+        super(OpTypes.CAST);
+
+        nodes         = new Expression[UNARY];
+        nodes[LEFT]   = e;
+        this.dataType = dataType;
+        this.alias    = e.alias;
+    }
+
     /**
      * creates a special conversion for time / timestamp comparison
      */
@@ -415,13 +429,6 @@ public class ExpressionOp extends Expression {
 
                 if (node.opType == OpTypes.VALUE) {
                     setAsConstantValue(session, parent);
-
-                    node.dataType  = dataType;
-                    node.valueData = valueData;
-
-                    if (parent != null) {
-                        parent.replaceNode(this, node);
-                    }
                 } else if (nodes[LEFT].opType == OpTypes.DYNAMIC_PARAM) {
                     node.dataType = dataType;
                 }
@@ -801,13 +808,6 @@ public class ExpressionOp extends Expression {
                     return new String(newArray, 0, j);
                 }
             }
-            case OpTypes.SIMPLE_COLUMN : {
-                Object value =
-                    session.sessionContext.rangeIterators[rangePosition]
-                        .getCurrent(columnIndex);
-
-                return value;
-            }
             case OpTypes.ORDER_BY :
                 return nodes[LEFT].getValue(session);
 
