@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -52,7 +52,7 @@ import org.hsqldb.types.Types;
  * Implementation of SQL standard function calls
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class FunctionSQL extends Expression {
@@ -162,6 +162,7 @@ public class FunctionSQL extends Expression {
         regularFuncMap.put(Tokens.T_CHARACTER_LENGTH, FUNC_CHAR_LENGTH);
         regularFuncMap.put(Tokens.T_OCTET_LENGTH, FUNC_OCTET_LENGTH);
         regularFuncMap.put(Tokens.T_CARDINALITY, FUNC_CARDINALITY);
+        regularFuncMap.put(Tokens.T_ARRAY_MAX_CARDINALITY, FUNC_MAX_CARDINALITY);
         regularFuncMap.put(Tokens.T_MAX_CARDINALITY, FUNC_MAX_CARDINALITY);
         regularFuncMap.put(Tokens.T_TRIM_ARRAY, FUNC_TRIM_ARRAY);
         regularFuncMap.put(Tokens.T_ABS, FUNC_ABS);
@@ -265,8 +266,6 @@ public class FunctionSQL extends Expression {
     protected FunctionSQL() {
 
         super(OpTypes.SQL_FUNCTION);
-
-        nodes = Expression.emptyArray;
     }
 
     protected FunctionSQL(int id) {
@@ -741,7 +740,9 @@ public class FunctionSQL extends Expression {
                 double d = ((Number) data[0]).doubleValue();
 
                 if (d <= 0) {
-                    throw Error.error(ErrorCode.X_2201E);
+                    if (session.database.sqlDoubleNaN) {
+                        throw Error.error(ErrorCode.X_2201E);
+                    }
                 }
 
                 d = Math.log(d);
@@ -785,6 +786,14 @@ public class FunctionSQL extends Expression {
                     return null;
                 }
 
+                double d = ((Number) data[0]).doubleValue();
+
+                if (d < 0) {
+                    if (session.database.sqlDoubleNaN) {
+                        throw Error.error(ErrorCode.X_2201E);
+                    }
+                }
+
                 double val = Math.sqrt(((Number) data[0]).doubleValue());
 
                 return ValuePool.getDouble(Double.doubleToLongBits(val));
