@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,7 @@ import org.hsqldb.types.Types;
  * Parser for SQL stored procedures and functions - PSM
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class ParserRoutine extends ParserTable {
@@ -362,6 +362,8 @@ public class ParserRoutine extends ParserTable {
 
         readRoutineBody(routine);
 
+        routine.resolve(session);
+
         return routine;
     }
 
@@ -2100,6 +2102,8 @@ public class ParserRoutine extends ParserTable {
 
         read();
 
+        Boolean ifNotExists = readIfNotExists();
+
         name = readNewSchemaObjectName(SchemaObject.TRIGGER, true);
 
         switch (token.tokenType) {
@@ -2469,7 +2473,7 @@ public class ParserRoutine extends ParserTable {
 
                 String     sql            = getLastPart();
                 Object[]   args           = new Object[] {
-                    td, otherName
+                    td, otherName, ifNotExists
                 };
                 HsqlName[] writeLockNames = new HsqlName[] {
                     database.getCatalogName(), table.getName()
@@ -2501,7 +2505,7 @@ public class ParserRoutine extends ParserTable {
 
         String   sql  = getLastPart();
         Object[] args = new Object[] {
-            td, otherName
+            td, otherName, ifNotExists
         };
 
         return new StatementSchema(sql, StatementTypes.CREATE_TRIGGER, args,
