@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ import org.hsqldb.types.Types;
  * Parser for SQL table definition
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.3.5
  * @since 1.9.0
  */
 public class ParserTable extends ParserDML {
@@ -445,12 +445,11 @@ public class ParserTable extends ParserDML {
             HsqlArrayList tempConstraints, HsqlArrayList constraintList,
             boolean addToSchema) {
 
-        Constraint c        = (Constraint) tempConstraints.get(0);
-        String     namePart = c.getName() == null ? null
-                                                  : c.getName().name;
-        HsqlName indexName = session.database.nameManager.newAutoName("IDX",
-            namePart, table.getSchemaName(), table.getName(),
-            SchemaObject.INDEX);
+        Constraint c = (Constraint) tempConstraints.get(0);
+        HsqlName indexName =
+            session.database.nameManager.newConstraintIndexName(
+                table.getName(), c.getName(),
+                session.database.sqlSysIndexNames);
 
         c.setColumnsIndexes(table);
         table.createPrimaryKey(indexName, c.core.mainCols, true);
@@ -481,9 +480,10 @@ public class ParserTable extends ParserDML {
                     }
 
                     // create an autonamed index
-                    indexName = session.database.nameManager.newAutoName("IDX",
-                            c.getName().name, table.getSchemaName(),
-                            table.getName(), SchemaObject.INDEX);
+                    indexName =
+                        session.database.nameManager.newConstraintIndexName(
+                            table.getName(), c.getName(),
+                            session.database.sqlSysIndexNames);
 
                     Index index = table.createAndAddIndexStructure(session,
                         indexName, c.core.mainCols, null, null, true, true,
@@ -587,8 +587,10 @@ public class ParserTable extends ParserDML {
             isForward = true;
         }
 
-        HsqlName refIndexName = session.database.nameManager.newAutoName("IDX",
-            table.getSchemaName(), table.getName(), SchemaObject.INDEX);
+        HsqlName refIndexName =
+            session.database.nameManager.newConstraintIndexName(
+                table.getName(), c.getName(),
+                session.database.sqlSysIndexNames);
         Index index = table.createAndAddIndexStructure(session, refIndexName,
             c.core.refCols, null, null, false, true, isForward);
         HsqlName mainName = session.database.nameManager.newAutoName("REF",
@@ -754,6 +756,10 @@ public class ParserTable extends ParserDML {
             }
         }
 
+        if (readIfThis(Tokens.NOT)) {
+            readThis(Tokens.DEFERRABLE);
+        }
+
         if (constraintName == null) {
             constraintName = database.nameManager.newAutoName("FK",
                     refTable.getSchemaName(), refTable.getName(),
@@ -1017,6 +1023,31 @@ public class ParserTable extends ParserDML {
         ColumnSchema column = new ColumnSchema(hsqlName, typeObject,
                                                isNullable, false, defaultExpr);
 
+        if (database.sqlSyntaxMys && typeObject.isDomainType()
+                && typeObject.getName().name.equals("ENUM")) {
+            typeObject.userTypeModifier = null;
+
+            HsqlName constName = database.nameManager.newAutoName("CT",
+                table.getSchemaName(), table.getName(),
+                SchemaObject.CONSTRAINT);
+            Constraint c = new Constraint(constName, null,
+                                          SchemaObject.ConstraintTypes.CHECK);
+
+            constraintList.add(c);
+            readThis(Tokens.OPENBRACKET);
+
+            Expression left  = new ExpressionColumn(column);
+            Expression right = super.XreadInValueListConstructor(1);
+
+            readThis(Tokens.CLOSEBRACKET);
+
+            ExpressionLogical in = new ExpressionLogical(OpTypes.IN, left,
+                right);
+
+            in.noOptimisation = true;
+            c.check           = in;
+        }
+
         column.setGeneratingExpression(generateExpr);
         readColumnConstraints(table, column, constraintList);
 
