@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -1026,8 +1026,8 @@ public class QueryExpression implements RangeGroup {
             for (int i = 0; i < unionColumnMap.length; i++) {
                 ColumnSchema column =
                     (ColumnSchema) columns.get(unionColumnMap[i]);
-
-                list.add(column.getName().name, column);
+                String name = (String) columns.getKey(unionColumnMap[i]);
+                list.add(name, column);
             }
 
             return list;
