@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,7 @@ import org.hsqldb.types.Type;
  * Metadata for range variables, including conditions.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class RangeVariable {
@@ -62,10 +62,11 @@ public class RangeVariable {
     static final RangeVariable[] emptyArray = new RangeVariable[]{};
 
     //
-    public static final int TABLE_RANGE      = 1;
-    public static final int TRANSITION_RANGE = 2;
-    public static final int PARAMETER_RANGE  = 3;
-    public static final int VARIALBE_RANGE   = 4;
+    public static final int TABLE_RANGE       = 1;
+    public static final int TRANSITION_RANGE  = 2;
+    public static final int PARAMETER_RANGE   = 3;
+    public static final int VARIALBE_RANGE    = 4;
+    public static final int PLACEHOLDER_RANGE = 5;
 
     //
     private static final RowIterator emptyIterator = new RangeIteratorEmpty();
@@ -115,6 +116,9 @@ public class RangeVariable {
     //
     int rangePosition;
 
+    //
+    boolean isViewSubquery;
+
     // for variable and parameter lists
     HashMappedList variables;
 
@@ -144,6 +148,7 @@ public class RangeVariable {
                 usedColumns = new boolean[variables.size()];
             case PARAMETER_RANGE :
             case VARIALBE_RANGE :
+            case PLACEHOLDER_RANGE :
                 break;
 
             default :
@@ -1166,9 +1171,7 @@ public class RangeVariable {
 
         public void reset() {
 
-            if (it != null) {
-                it.release();
-            }
+            it.release();
 
             it            = emptyIterator;
             isBeforeFirst = true;
@@ -1183,10 +1186,7 @@ public class RangeVariable {
         }
 
         public void release() {
-
-            if (it != null) {
-                it.release();
-            }
+            it.release();
         }
     }
 
@@ -1257,7 +1257,10 @@ public class RangeVariable {
                     return true;
                 }
 
-                reset();
+                it.release();
+
+                it            = emptyIterator;
+                isBeforeFirst = true;
 
                 condIndex++;
             }
@@ -1271,12 +1274,11 @@ public class RangeVariable {
 
         public void reset() {
 
-            if (it != null) {
-                it.release();
-            }
+            it.release();
 
             it            = emptyIterator;
             isBeforeFirst = true;
+            condIndex     = 0;
         }
 
         public int getRangePosition() {
@@ -1671,9 +1673,7 @@ public class RangeVariable {
 
         public void release() {
 
-            if (it != null) {
-                it.release();
-            }
+            it.release();
 
             for (int i = 0; i < rangeIterators.length; i++) {
                 rangeIterators[i].reset();
