@@ -85,7 +85,7 @@ import org.hsqldb.rowio.RowOutputInterface;
 // fredt@users 20020920 - patch 1.7.1 - refactoring to cut memory footprint
 // fredt@users 20021205 - patch 1.7.2 - enhancements
 // fredt@users 20021215 - doc 1.7.2 - javadoc comments
-// boucherb@users - 20040411 - doc 1.7.2 - javadoc comments
+// campbell-burnet@users - 20040411 - doc 1.7.2 - javadoc comments
 
 /**
  *  In-memory representation of a disk-based database row object with  methods
@@ -95,7 +95,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  *
  * @author Fred Toussi (fredt@users dot sourceforge dot net)
  * @author Thomas Mueller (Hypersonic SQL Group)
- * @version 2.3.4
+ * @version 2.3.5
  * @since Hypersonic SQL
  */
 public class RowAVLDisk extends RowAVL {
@@ -142,14 +142,15 @@ public class RowAVLDisk extends RowAVL {
      * @param in data source
      * @throws IOException
      */
-    public RowAVLDisk(TableBase t, RowInputInterface in) throws IOException {
+    public RowAVLDisk(PersistentStore store,
+                      RowInputInterface in) throws IOException {
 
-        super(t, (Object[]) null);
+        super(store.getTable(), (Object[]) null);
 
-        position    = in.getPos();
+        position    = in.getFilePosition();
         storageSize = in.getSize();
 
-        int indexcount = t.getIndexCount();
+        int indexcount = store.getAccessorKeys().length;
 
         nPrimaryNode = new NodeAVLDisk(this, in, 0);
 
