@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,7 @@ import org.hsqldb.types.Type;
  * Manages all SCHEMA related database objects
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.8.0
  */
 public class SchemaManager {
@@ -849,8 +849,7 @@ public class SchemaManager {
 
     private void dropTable(Session session, Table table, boolean cascade) {
 
-        Schema schema    = (Schema) schemaMap.get(table.getSchemaName().name);
-        int    dropIndex = schema.tableList.getIndex(table.getName().name);
+        Schema schema = (Schema) schemaMap.get(table.getSchemaName().name);
         OrderedHashSet externalConstraints =
             table.getDependentExternalConstraints();
         OrderedHashSet externalReferences = new OrderedHashSet();
@@ -923,7 +922,7 @@ public class SchemaManager {
         removeReferencesTo(uniqueConstraintNames);
         removeReferencesTo(table.getName());
         removeReferencesFrom(table);
-        schema.tableList.remove(dropIndex);
+        schema.tableList.remove(table.getName().name);
         schema.indexLookup.removeParent(table.getName());
         schema.constraintLookup.removeParent(table.getName());
         schema.triggerLookup.removeParent(table.getName());
@@ -1128,7 +1127,7 @@ public class SchemaManager {
                                          false);
 
         if (seq == null && schemaName == null) {
-            schemaName = session.getSchemaName(schemaName);
+            schemaName = session.getSchemaName(null);
 
             ReferenceObject ref = findSynonym(name, schemaName,
                                               SchemaObject.SEQUENCE);
@@ -1436,7 +1435,8 @@ public class SchemaManager {
         return reference;
     }
 
-    public SchemaObject findAnySchemaObject(String name, String schemaName) {
+    public SchemaObject findAnySchemaObjectForSynonym(String name,
+            String schemaName) {
 
         readLock.lock();
 
@@ -1447,7 +1447,7 @@ public class SchemaManager {
                 return null;
             }
 
-            return schema.findAnySchemaObject(name);
+            return schema.findAnySchemaObjectForSynonym(name);
         } finally {
             readLock.unlock();
         }
@@ -1650,6 +1650,10 @@ public class SchemaManager {
         OrderedHashSet set  = object.getReferences();
         HsqlName       name = object.getName();
 
+        if (object instanceof Routine) {
+            name = ((Routine) object).getSpecificName();
+        }
+
         if (set == null) {
             return;
         }
@@ -1657,10 +1661,6 @@ public class SchemaManager {
         for (int i = 0; i < set.size(); i++) {
             HsqlName referenced = (HsqlName) set.get(i);
 
-            if (object instanceof Routine) {
-                name = ((Routine) object).getSpecificName();
-            }
-
             referenceMap.put(referenced, name);
         }
     }
@@ -1683,6 +1683,10 @@ public class SchemaManager {
         HsqlName       name = object.getName();
         OrderedHashSet set  = object.getReferences();
 
+        if (object instanceof Routine) {
+            name = ((Routine) object).getSpecificName();
+        }
+
         if (set == null) {
             return;
         }
@@ -1690,10 +1694,6 @@ public class SchemaManager {
         for (int i = 0; i < set.size(); i++) {
             HsqlName referenced = (HsqlName) set.get(i);
 
-            if (object instanceof Routine) {
-                name = ((Routine) object).getSpecificName();
-            }
-
             referenceMap.remove(referenced, name);
         }
     }
@@ -2233,7 +2233,17 @@ public class SchemaManager {
             for (int i = 0; i < set.size(); i++) {
                 HsqlName name = (HsqlName) set.get(i);
 
-                removeSchemaObject(name);
+                if (name.parent != null) {
+                    removeSchemaObject(name);
+                }
+            }
+
+            for (int i = 0; i < set.size(); i++) {
+                HsqlName name = (HsqlName) set.get(i);
+
+                if (name.parent == null) {
+                    removeSchemaObject(name);
+                }
             }
         } finally {
             writeLock.unlock();
@@ -2448,6 +2458,7 @@ public class SchemaManager {
 
             schemas = schemaMap.values().iterator();
 
+            // build up set of simple objects
             while (schemas.hasNext()) {
                 Schema schema = (Schema) schemas.next();
 
@@ -2463,6 +2474,7 @@ public class SchemaManager {
                 schema.addSimpleObjects(unresolved);
             }
 
+            // list all simple objects in refernece order
             while (true) {
                 Iterator it = unresolved.iterator();
 
@@ -2483,6 +2495,7 @@ public class SchemaManager {
 
             schemas = schemaMap.values().iterator();
 
+            //
             while (schemas.hasNext()) {
                 Schema schema = (Schema) schemas.next();
 
@@ -2700,7 +2713,7 @@ public class SchemaManager {
         }
     }
 
-    public String[] getCommentsArray() {
+    public String[] getCommentsSQL() {
 
         readLock.lock();
 
