@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2011, The HSQL Development Group
+/* Copyright (c) 2001-2016, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,7 +42,7 @@ import org.hsqldb.error.ErrorCode;
  * @version 2.3.1
  * @since 1.9.0
  */
-public class SqlInvariants {
+public final class SqlInvariants {
 
     /**
      * The role name reserved for authorization of INFORMATION_SCHEMA and
@@ -114,14 +114,14 @@ public class SqlInvariants {
         SYSTEM_SUBQUERY_HSQLNAME.setSchemaIfNull(SYSTEM_SCHEMA_HSQLNAME);
     }
 
-    public static final void checkSchemaNameNotSystem(String name) {
+    public static void checkSchemaNameNotSystem(String name) {
 
         if (isSystemSchemaName(name)) {
             throw Error.error(ErrorCode.X_42503, name);
         }
     }
 
-    public static final boolean isSystemSchemaName(String name) {
+    public static boolean isSystemSchemaName(String name) {
 
         if (SqlInvariants.DEFINITION_SCHEMA.equals(name)
                 || SqlInvariants.INFORMATION_SCHEMA.equals(name)
@@ -133,7 +133,7 @@ public class SqlInvariants {
         return false;
     }
 
-    public static final boolean isLobsSchemaName(String name) {
+    public static boolean isLobsSchemaName(String name) {
 
         if (SqlInvariants.LOBS_SCHEMA.equals(name)) {
             return true;
@@ -142,7 +142,7 @@ public class SqlInvariants {
         return false;
     }
 
-    public static final boolean isSchemaNameSystem(HsqlName name) {
+    public static boolean isSchemaNameSystem(HsqlName name) {
 
         if (name.schema != null) {
             name = name.schema;
