@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -358,7 +358,7 @@ public class StatementDML extends StatementDMQL {
     public void setGeneratedColumnInfo(int generate, ResultMetaData meta) {
 
         // also supports INSERT_SELECT
-        if (type != StatementTypes.INSERT) {
+        if (type != StatementTypes.INSERT && type != StatementTypes.MERGE) {
             return;
         }
 
