@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,7 @@ import org.hsqldb.types.Type;
  * Implementation of Statement for DDL statements.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class StatementSchema extends Statement {
@@ -438,8 +438,8 @@ public class StatementSchema extends Statement {
                         case StatementTypes.ADD_CONSTRAINT : {
                             Constraint c = (Constraint) arguments[2];
 
-                            session.database.schemaManager
-                                .checkSchemaObjectNotExists(c.getName());
+                            setOrCheckObjectName(session, domain.getName(),
+                                                 c.getName(), true);
                             domain.userTypeModifier.addConstraint(c);
                             session.database.schemaManager.addSchemaObject(c);
 
@@ -652,8 +652,6 @@ public class StatementSchema extends Statement {
                 Routine routine = (Routine) arguments[0];
 
                 try {
-                    routine.resolveReferences(session);
-
                     Routine oldRoutine =
                         (Routine) schemaManager.getSchemaObject(
                             routine.getSpecificName());
@@ -1108,7 +1106,6 @@ public class StatementSchema extends Statement {
                 Routine routine = (Routine) arguments[0];
 
                 try {
-                    routine.resolve(session);
                     setOrCheckObjectName(session, null, routine.getName(),
                                          false);
                     schemaManager.addSchemaObject(routine);
@@ -1213,7 +1210,7 @@ public class StatementSchema extends Statement {
                     table.compile(session, null);
                     schemaManager.addSchemaObject(table);
 
-                    if (tempIndexes != null) {
+                    if (tempIndexes != null && !tempIndexes.isEmpty()) {
                         TableWorks tableWorks = new TableWorks(session, table);
 
                         for (int i = 0; i < tempIndexes.size(); i++) {
@@ -1234,17 +1231,17 @@ public class StatementSchema extends Statement {
                         }
 
                         table.insertIntoTable(session, result);
-                    }
 
-                    if (table.hasLobColumn) {
-                        RowIterator it = table.rowIterator(session);
+                        if (table.hasLobColumn) {
+                            RowIterator it = table.rowIterator(session);
 
-                        while (it.next()) {
-                            Row      row  = it.getCurrentRow();
-                            Object[] data = row.getData();
+                            while (it.next()) {
+                                Row      row  = it.getCurrentRow();
+                                Object[] data = row.getData();
 
-                            session.sessionData.adjustLobUsageCount(table,
-                                    data, 1);
+                                session.sessionData.adjustLobUsageCount(table,
+                                        data, 1);
+                            }
                         }
                     }
 
@@ -1263,14 +1260,13 @@ public class StatementSchema extends Statement {
                 return Result.updateZeroResult;
 
             case StatementTypes.CREATE_TRIGGER : {
-                TriggerDef trigger   = (TriggerDef) arguments[0];
-                HsqlName   otherName = (HsqlName) arguments[1];
+                TriggerDef trigger     = (TriggerDef) arguments[0];
+                HsqlName   otherName   = (HsqlName) arguments[1];
+                Boolean    ifNotExists = (Boolean) arguments[2];
 
                 try {
-                    checkSchemaUpdateAuthorisation(session,
-                                                   trigger.getSchemaName());
-                    schemaManager.checkSchemaObjectNotExists(
-                        trigger.getName());
+                    setOrCheckObjectName(session, null, trigger.getName(),
+                                         true);
 
                     if (otherName != null) {
                         if (schemaManager.getSchemaObject(otherName) == null) {
@@ -1285,7 +1281,11 @@ public class StatementSchema extends Statement {
 
                     break;
                 } catch (HsqlException e) {
-                    return Result.newErrorResult(e, sql);
+                    if (ifNotExists != null && ifNotExists.booleanValue()) {
+                        return Result.updateZeroResult;
+                    } else {
+                        return Result.newErrorResult(e, sql);
+                    }
                 }
             }
             case StatementTypes.CREATE_CAST :
@@ -1384,13 +1384,13 @@ public class StatementSchema extends Statement {
 
                 setSchemaName(session, null, name);
                 setSchemaName(session, null, targetName);
-                session.database.schemaManager.checkSchemaObjectNotExists(
-                    name);
+                setOrCheckObjectName(session, null, name, true);
 
                 // find the new target
                 SchemaObject object =
-                    session.database.schemaManager.findAnySchemaObject(
-                        targetName.name, targetName.schema.name);
+                    session.database.schemaManager
+                        .findAnySchemaObjectForSynonym(targetName.name,
+                                                       targetName.schema.name);
 
                 if (object == null) {
                     throw Error.error(ErrorCode.X_42501);
@@ -1580,6 +1580,8 @@ public class StatementSchema extends Statement {
 
     private void dropObject(Session session, HsqlName name, boolean cascade) {
 
+        checkSchemaUpdateAuthorisation(session, name.schema);
+
         name = session.database.schemaManager.getSchemaObjectName(name.schema,
                 name.name, name.type, true);
 
@@ -1637,7 +1639,9 @@ public class StatementSchema extends Statement {
             }
         }
 
-        name.parent = parent;
+        if (name.parent == null) {
+            name.parent = parent;
+        }
 
         if (!isSchemaDefinition) {
             checkSchemaUpdateAuthorisation(session, name.schema);
