@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -167,7 +167,7 @@ public class StatementSimple extends Statement {
         return "";
     }
 
-    public boolean isCatalogLock() {
+    public boolean isCatalogLock(int model) {
         return false;
     }
 
