@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -62,7 +62,7 @@ import org.hsqldb.types.Type;
  * Holds the data structures and methods for creation of a named database table.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.6.1
  */
 public class Table extends TableBase implements SchemaObject {
@@ -3055,24 +3055,6 @@ public class Table extends TableBase implements SchemaObject {
         return index.firstRow(store);
     }
 
-    public void clearAllData(Session session) {
-
-        super.clearAllData(session);
-
-        if (identitySequence != null) {
-            identitySequence.reset();
-        }
-    }
-
-    public void clearAllData(PersistentStore store) {
-
-        super.clearAllData(store);
-
-        if (identitySequence != null) {
-            identitySequence.reset();
-        }
-    }
-
     /**
      * Path used for all stores
      */
