@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,7 @@ import org.hsqldb.types.Types;
  * existing table which may result in a new Table object
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.3.5
  * @since 1.7.0
  */
 public class TableWorks {
@@ -203,8 +203,10 @@ public class TableWorks {
         HsqlName mainName = database.nameManager.newAutoName("REF",
             c.getName().name, table.getSchemaName(), table.getName(),
             SchemaObject.INDEX);
-        HsqlName indexName = database.nameManager.newAutoName("IDX",
-            table.getSchemaName(), table.getName(), SchemaObject.INDEX);
+        HsqlName indexName =
+            session.database.nameManager.newConstraintIndexName(
+                table.getName(), c.getName(),
+                session.database.sqlSysIndexNames);
         Index refIndex = table.createIndexStructure(indexName, c.core.refCols,
             null, null, false, true, isForward);
 
@@ -237,6 +239,7 @@ public class TableWorks {
         mainTable.addConstraint(new Constraint(mainName, c));
         updateConstraints(tn, emptySet);
         database.schemaManager.recompileDependentObjects(tn);
+        database.schemaManager.recompileDependentObjects(mainTable);
 
         table = tn;
     }
@@ -571,6 +574,7 @@ public class TableWorks {
         indexes[position] = newIndex;
 
         store.reindex(session, newIndex);
+        database.schemaManager.recompileDependentObjects(table);
     }
 
     /**
@@ -748,7 +752,7 @@ public class TableWorks {
 
         checkModifyTable(false);
 
-        index = table.getIndex(indexName);
+        index = table.getUserIndex(indexName);
 
         if (table.isIndexingMutable()) {
             table.dropIndex(session, index.getPosition());
@@ -1151,8 +1155,8 @@ public class TableWorks {
         int         colIndex = table.getColumnIndex(oldCol.getName().name);
         RowIterator it       = table.rowIterator(session);
 
-        while (it.hasNext()) {
-            Row    row = it.getNextRow();
+        while (it.next()) {
+            Row    row = it.getCurrentRow();
             Object o   = row.getData()[colIndex];
 
             if (!newCol.isNullable() && o == null) {
