@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,7 @@ import org.hsqldb.lib.OrderedHashSet;
  * Shared code for TransactionManager classes
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.3.5
  * @since 2.0.0
  */
 class TransactionManagerCommon {
@@ -73,17 +73,25 @@ class TransactionManagerCommon {
     AtomicLong globalChangeTimestamp = new AtomicLong(1);
 
     //
-    int transactionCount = 0;
+    long transactionCount = 0;
 
     //
     HashMap           tableWriteLocks = new HashMap();
     MultiValueHashMap tableReadLocks  = new MultiValueHashMap();
 
+    //
+    volatile boolean hasExpired;
+
     // functional unit - cached table transactions
 
     /** Map : rowID -> RowAction */
     public LongKeyHashMap rowActionMap;
 
+    TransactionManagerCommon(Database database) {
+        this.database   = database;
+        catalogNameList = new HsqlName[]{ database.getCatalogName() };
+    }
+
     void setTransactionControl(Session session, int mode) {
 
         TransactionManagerCommon manager = null;
@@ -108,11 +116,25 @@ class TransactionManagerCommon {
             switch (mode) {
 
                 case TransactionManager.MVCC : {
-                    manager = new TransactionManagerMVCC(database);
+                    TransactionManagerMVCC txMan =
+                        new TransactionManagerMVCC(database);
 
-                    manager.liveTransactionTimestamps.addLast(
+                    txMan.liveTransactionTimestamps.addLast(
                         session.transactionTimestamp);
 
+                    txMan.catalogWriteSession = session;
+                    txMan.isLockedMode        = true;
+
+                    OrderedHashSet set = session.waitingSessions;
+
+                    for (int i = 0; i < set.size(); i++) {
+                        Session current = (Session) set.get(i);
+
+                        current.waitedSessions.add(session);
+                    }
+
+                    manager = txMan;
+
                     break;
                 }
                 case TransactionManager.MVLOCKS : {
@@ -121,11 +143,27 @@ class TransactionManagerCommon {
                     manager.liveTransactionTimestamps.addLast(
                         session.transactionTimestamp);
 
+                    OrderedHashSet set = session.waitingSessions;
+
+                    for (int i = 0; i < set.size(); i++) {
+                        Session current = (Session) set.get(i);
+
+                        current.waitedSessions.clear();
+                    }
+
                     break;
                 }
                 case TransactionManager.LOCKS : {
                     manager = new TransactionManager2PL(database);
 
+                    OrderedHashSet set = session.waitingSessions;
+
+                    for (int i = 0; i < set.size(); i++) {
+                        Session current = (Session) set.get(i);
+
+                        current.waitedSessions.clear();
+                    }
+
                     break;
                 }
                 default :
@@ -136,6 +174,7 @@ class TransactionManagerCommon {
             manager.globalChangeTimestamp.set(globalChangeTimestamp.get());
 
             manager.transactionCount = transactionCount;
+            hasExpired               = true;
             database.txManager       = (TransactionManager) manager;
         } finally {
             writeLock.unlock();
@@ -191,6 +230,17 @@ class TransactionManagerCommon {
         }
     }
 
+    Statement updateCurrentStatement(Session session, Statement cs) {
+
+        if (cs.getCompileTimestamp()
+                < database.schemaManager.getSchemaChangeTimestamp()) {
+            cs = session.statementManager.getStatement(session, cs);
+            session.sessionContext.currentStatement = cs;
+        }
+
+        return cs;
+    }
+
     void persistCommit(Session session) {
 
         int     limit       = session.rowActionList.size();
@@ -495,20 +545,27 @@ class TransactionManagerCommon {
         final int waitingCount = session.waitingSessions.size();
 
         for (int i = 0; i < waitingCount; i++) {
-            Session current = (Session) session.waitingSessions.get(i);
+            Session current  = (Session) session.waitingSessions.get(i);
+            boolean testCode = false;
 
-/*
-            if (!current.abortTransaction && current.tempSet.isEmpty()) {
+            if (testCode) {
+                if (!current.abortTransaction && current.tempSet.isEmpty()) {
 
+                    // test code valid only for top level statements
+                    boolean hasLocks =
+                        hasLocks(current,
+                                 current.sessionContext.currentStatement);
 
-                // test code valid only for top level statements
-                boolean hasLocks = hasLocks(current, current.sessionContext.currentStatement);
-                if (!hasLocks) {
-                    System.out.println("trouble");
+                    if (!hasLocks) {
+                        System.out.println("tx graph");
+
+                        hasLocks =
+                            hasLocks(current,
+                                     current.sessionContext.currentStatement);
+                    }
                 }
-
             }
-*/
+
             setWaitingSessionTPL(current);
         }
 
@@ -525,16 +582,25 @@ class TransactionManagerCommon {
         final int waitingCount = session.tempSet.size();
 
         for (int i = 0; i < waitingCount; i++) {
-            Session current = (Session) session.tempSet.get(i);
+            Session current  = (Session) session.tempSet.get(i);
+            boolean testCode = false;
 
-            if (!current.abortTransaction && current.tempSet.isEmpty()) {
+            if (testCode) {
+                if (!current.abortTransaction && current.tempSet.isEmpty()) {
 
-                // valid for top level statements
-//                boolean hasLocks = hasLocks(current, current.sessionContext.currentStatement);
-//                if (!hasLocks) {
-//                    System.out.println("trouble");
-//                    hasLocks(current, current.sessionContext.currentStatement);
-//                }
+                    // test code valid for top level statements
+                    boolean hasLocks =
+                        hasLocks(current,
+                                 current.sessionContext.currentStatement);
+
+                    if (!hasLocks) {
+                        System.out.println("tx graph");
+
+                        hasLocks =
+                            hasLocks(current,
+                                     current.sessionContext.currentStatement);
+                    }
+                }
             }
 
             setWaitingSessionTPL(current);
@@ -555,7 +621,7 @@ class TransactionManagerCommon {
             return false;
         }
 
-        if (cs.isCatalogLock()) {
+        if (cs.isCatalogLock(txModel)) {
             getTransactionSessions(session);
         }
 
