@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,14 +42,14 @@ import org.hsqldb.types.DateTimeType;
 import org.hsqldb.types.IntervalType;
 import org.hsqldb.types.Type;
 
-/* $Id: JDBCParameterMetaData.java 5561 2016-03-18 18:39:11Z fredt $ */
+/* $Id: JDBCParameterMetaData.java 5721 2017-03-14 11:31:10Z fredt $ */
 
 /** @todo 1.9.0 - implement internal support for INOUT, OUT return parameter */
 
 // fredt@users 20040412 - removed DITypeInfo dependencies
 // fredt@users 1.9.0 - utilise the new type support
-// boucherb@users 20051207 - patch 1.8.0.x initial JDBC 4.0 support work
-// boucherb@users 20060522 - doc   1.9.0 full synch up to Mustang Build 84
+// campbell-burnet@users 20051207 - patch 1.8.0.x initial JDBC 4.0 support work
+// campbell-burnet@users 20060522 - doc   1.9.0 full synch up to Mustang Build 84
 // Revision 1.14  2006/07/12 12:20:49  boucherb
 // - remove unused imports
 // - full synch up to Mustang b90
@@ -66,7 +66,7 @@ import org.hsqldb.types.Type;
  * types and properties for each parameter marker in a <code>CallableStatement</code>
  * object.
  *
- * @author Campbell Burnet (boucherb@users dot sourceforge.net)
+ * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @version 2.3.4
  * @since JDK 1.4, HSQLDB 1.7.2
  * @revised JDK 1.6, HSQLDB 2.0
@@ -348,8 +348,6 @@ public class JDBCParameterMetaData
         if (this.translateTTIType) {
             if (type.isIntervalType()) {
                 type = ((IntervalType) type).getCharacterType();
-            } else if (type.isDateTimeTypeWithZone()) {
-                type = ((DateTimeType) type).getDateTimeTypeWithoutZone();
             }
         }
 
