@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@ import java.lang.reflect.Array;
  * Collection of static methods for operations on arrays
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.3.5
  * @since 1.7.2
  */
 public class ArrayUtil {
@@ -94,7 +94,7 @@ public class ArrayUtil {
                 return;
             }
             case ArrayUtil.CLASS_CODE_CHAR : {
-                byte[] array = (byte[]) data;
+                char[] array = (char[]) data;
 
                 while (--to >= from) {
                     array[to] = 0;
@@ -1617,6 +1617,19 @@ public class ArrayUtil {
         return bytes;
     }
 
+    public static long byteSequenceToLong(byte[] bytes, int pos) {
+
+        long val = 0;
+
+        for (int i = 0; i < 8; i++) {
+            long b = bytes[pos + i] & 0xff;
+
+            val += (b << ((7 - i) * 8));
+        }
+
+        return val;
+    }
+
     /**
      * Compares two arrays. Returns -1, 0, +1. If one array is shorter and
      * all the elements are equal to the other's elements, -1 is returned.
