@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -52,11 +52,13 @@ import org.hsqldb.lib.java.JavaSystem;
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  * @author Ocke Janssen oj@openoffice.org
- * @version 2.3.4
+ * @version 2.4.1
  * @since 1.7.2
  */
 public class FileUtil implements FileAccess {
 
+    private static final FrameworkLogger LOG =
+        FrameworkLogger.getLog(FileUtil.class);
     private static FileUtil      fileUtil      = new FileUtil();
     private static FileAccessRes fileAccessRes = new FileAccessRes();
 
@@ -97,13 +99,66 @@ public class FileUtil implements FileAccess {
         }
     }
 
-    public void renameElement(String oldName, String newName) {
-        renameWithOverwrite(oldName, newName);
+    public void renameElement(String oldName, String newName,
+                              boolean copyIfFailed) {
+
+        if (renameWithOverwrite(oldName, newName)) {
+            return;
+        }
+
+        if (!copyIfFailed) {
+            return;
+        }
+
+        InputStream  inputStream  = null;
+        OutputStream outputStream = null;
+
+        try {
+            inputStream  = openInputStreamElement(oldName);
+            outputStream = openOutputStreamElement(newName, false);
+
+            InOutUtil.copy(inputStream, outputStream);
+            getFileSync(outputStream).sync();
+        } catch (IOException e) {
+            String message = String.format(
+                "Platform does not allow renaming files and failed to copy file contents from %s to %s",
+                oldName, newName);
+
+            LOG.error(message, e);
+
+            return;
+        } finally {
+            try {
+                if (inputStream != null) {
+                    inputStream.close();
+                }
+            } catch (IOException e) {
+                LOG.finest("Failed to dispose streams", e);
+            }
+
+            try {
+                if (outputStream != null) {
+                    outputStream.close();
+                }
+            } catch (IOException e) {
+                LOG.finest("Failed to dispose streams", e);
+            }
+        }
+
+        if (!delete(oldName)) {
+            LOG.warning("Failed to delete renamed file " + oldName);
+        }
+
+        String message = String.format(
+            "Platform does not allow renaming files. Copied file from %s to %s instead",
+            oldName, newName);
+
+        LOG.finer(message);
     }
 
-    public OutputStream openOutputStreamElement(String streamName)
-    throws IOException {
-        return new FileOutputStream(new File(streamName), true);
+    public OutputStream openOutputStreamElement(String streamName,
+            boolean append) throws IOException {
+        return new FileOutputStream(new File(streamName), append);
     }
 
     // end of FileAccess implementation
@@ -378,10 +433,11 @@ public class FileUtil implements FileAccess {
 
         public void removeElement(String filename) {}
 
-        public void renameElement(String oldName, String newName) {}
+        public void renameElement(String oldName, String newName,
+                                  boolean copyIfFailed) {}
 
-        public OutputStream openOutputStreamElement(String streamName)
-        throws IOException {
+        public OutputStream openOutputStreamElement(String streamName,
+                boolean append) throws IOException {
             throw new IOException();
         }
 
