@@ -32,27 +32,26 @@
 package org.hsqldb.navigator;
 
 import org.hsqldb.Row;
-import org.hsqldb.TableBase;
 
 /**
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.3.5
  * @since 1.7.2
  */
 public interface RowIterator {
 
-    Row getNextRow();
+    Object getField(int col);
 
-    Object[] getNext();
+    boolean next();
 
-    boolean hasNext();
+    Row getCurrentRow();
+
+    Object[] getCurrent();
 
     void removeCurrent();
 
     void release();
 
     long getRowId();
-
-    TableBase getCurrentTable();
 }
