@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -133,7 +133,7 @@ implements Comparator {
 
         mainIndex = fullIndex;
 
-        ArraySort.sort(dataTable, 0, size, this);
+        ArraySort.sort(dataTable, size, this);
         reset();
     }
 
@@ -142,7 +142,7 @@ implements Comparator {
         if (orderIndex != null) {
             mainIndex = orderIndex;
 
-            ArraySort.sort(dataTable, 0, size, this);
+            ArraySort.sort(dataTable, size, this);
         }
 
         reset();
@@ -153,7 +153,7 @@ implements Comparator {
         if (sortAndSlice.index != null) {
             mainIndex = sortAndSlice.index;
 
-            ArraySort.sort(dataTable, 0, size, this);
+            ArraySort.sort(dataTable, size, this);
             reset();
         }
     }
