@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  * Implementation of RowSetNavigator using a table as the data store.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class RowSetNavigatorDataTable extends RowSetNavigatorData {
@@ -65,7 +65,7 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
         super(session);
 
-        this.rangePosition = select.resultRangePosition;
+        rangePosition      = select.resultRangePosition;
         visibleColumnCount = select.indexLimitVisible;
         table              = select.resultTable.duplicate();
         store = session.sessionData.getNewResultRowStore(table,
@@ -272,7 +272,7 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
     public void clear() {
 
-        table.clearAllData(store);
+        store.removeAll();
 
         size = 0;
 
