@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,7 +43,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  */
 public class BitMapCachedObject extends CachedObjectBase {
 
-    public final static int fileSizeFactor = 4;
+    public static final int fileSizeFactor = 4;
 
     //
     BitMap bitMap;
