@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@ import org.hsqldb.map.BaseHashMap;
  * to DataFileCache.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.4.1
  * @since 1.8.0
  */
 public class Cache extends BaseHashMap {
@@ -101,9 +101,7 @@ public class Cache extends BaseHashMap {
     public CachedObject get(long pos) {
 
         if (accessCount > ACCESS_MAX) {
-            updateAccessCounts();
-            resetAccessCount();
-            updateObjectAccessCounts();
+            updateAndResetAccessCounts();
         }
 
         int lookup = getObjectLookup(pos);
@@ -119,6 +117,15 @@ public class Cache extends BaseHashMap {
         return object;
     }
 
+    private synchronized void updateAndResetAccessCounts() {
+
+        if (accessCount > ACCESS_MAX) {
+            updateAccessCounts();
+            resetAccessCount();
+            updateObjectAccessCounts();
+        }
+    }
+
     /**
      * Adds a row to the cache.
      */
@@ -395,14 +402,14 @@ public class Cache extends BaseHashMap {
         }
     }
 
-    private synchronized void saveRows(int count) {
+    private void saveRows(int count) {
 
         if (count == 0) {
             return;
         }
 
         rowComparator.setType(CachedObjectComparator.COMPARE_POSITION);
-        ArraySort.sort(rowTable, 0, count, rowComparator);
+        ArraySort.sort(rowTable, count, rowComparator);
         dataFileCache.saveRows(rowTable, 0, count);
 
         saveRowCount += count;
@@ -483,17 +490,21 @@ public class Cache extends BaseHashMap {
         static final int COMPARE_POSITION    = 1;
         static final int COMPARE_SIZE        = 2;
         private int      compareType         = COMPARE_POSITION;
+        private long     compareCount;
 
         CachedObjectComparator() {}
 
         void setType(int type) {
-            compareType = type;
+            compareType  = type;
+            compareCount = 0;
         }
 
         public int compare(Object a, Object b) {
 
             long diff;
 
+            compareCount++;
+
             switch (compareType) {
 
                 case COMPARE_POSITION :
