@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -305,7 +305,7 @@ public class Log {
         if (fa.isStreamElement(scriptFileName + Logger.newFileExtension)) {
             fa.removeElement(scriptFileName);
             fa.renameElement(scriptFileName + Logger.newFileExtension,
-                             scriptFileName);
+                             scriptFileName, true);
         }
     }
 
