@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -395,7 +395,7 @@ public class Logger implements EventLogInterface {
             checkpoint(null, false, false);
         }
 
-        if (database.getNameString().isEmpty()) {
+        if (database.getNameString().length() == 0) {
             database.setDatabaseName(newUniqueName());
         }
 
@@ -425,8 +425,10 @@ public class Logger implements EventLogInterface {
                 HsqlDatabaseProperties.url_crypt_type);
             String cryptProvider = database.urlProperties.getProperty(
                 HsqlDatabaseProperties.url_crypt_provider);
+            String cryptIv = database.urlProperties.getProperty(
+                HsqlDatabaseProperties.url_crypt_iv);
 
-            crypto = new Crypto(cryptKey, cryptType, cryptProvider);
+            crypto = new Crypto(cryptKey, cryptIv, cryptType, cryptProvider);
             cryptLobs = database.urlProperties.isPropertyTrue(
                 HsqlDatabaseProperties.url_crypt_lobs, true);
         }
@@ -800,7 +802,7 @@ public class Logger implements EventLogInterface {
 
         String name = database.getNameString();
 
-        if (name.isEmpty()) {
+        if (name.length() == 0) {
 
             // The database unique name is set up at different times
             // depending on upgraded / exiting / new databases.
@@ -2274,7 +2276,7 @@ public class Logger implements EventLogInterface {
         }
     }
 
-    SimpleDateFormat backupFileFormat =
+    public SimpleDateFormat fileDateFormat =
         new SimpleDateFormat("yyyyMMdd'T'HHmmss");
     private static char runtimeFileDelim =
         System.getProperty("file.separator").charAt(0);
@@ -2328,7 +2330,7 @@ public class Logger implements EventLogInterface {
                 archiveFile =
                     (new File(destPath.substring(0, destPath.length() - 1),
                               instanceName + '-'
-                              + backupFileFormat.format(new java.util.Date())
+                              + fileDateFormat.format(new java.util.Date())
                               + defaultSuffix));
             } else {
                 archiveFile = new File(destPath);
