@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,8 @@
 
 package org.hsqldb.persist;
 
+import java.util.concurrent.atomic.AtomicLong;
+
 import org.hsqldb.Database;
 import org.hsqldb.TableBase;
 import org.hsqldb.lib.Iterator;
@@ -38,14 +40,14 @@ import org.hsqldb.lib.LongKeyHashMap;
 
 /**
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.4.1
  * @since 1.9.0
  */
 public class PersistentStoreCollectionDatabase
 implements PersistentStoreCollection {
 
     private Database             database;
-    private long                 persistentStoreIdSequence;
+    private AtomicLong           persistentStoreIdSequence = new AtomicLong();
     private final LongKeyHashMap rowStoreMap = new LongKeyHashMap();
 
     public PersistentStoreCollectionDatabase(Database db) {
@@ -99,7 +101,7 @@ implements PersistentStoreCollection {
     }
 
     public long getNextId() {
-        return persistentStoreIdSequence++;
+        return persistentStoreIdSequence.getAndIncrement();
     }
 
     public void setNewTableSpaces() {
