@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2017, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,6 @@ import org.hsqldb.RowAction;
 import org.hsqldb.Session;
 import org.hsqldb.Table;
 import org.hsqldb.TableBase;
-import org.hsqldb.TransactionManager;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
@@ -54,13 +53,14 @@ import org.hsqldb.index.NodeAVL;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.navigator.RowIterator;
 import org.hsqldb.rowio.RowInputInterface;
+import org.hsqldb.types.LobData;
 import org.hsqldb.types.Type;
 
 /*
  * Base implementation of PersistentStore for different table types.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.3.5
  * @since 1.9.0
  */
 public abstract class RowStoreAVL implements PersistentStore {
@@ -309,8 +309,8 @@ public abstract class RowStoreAVL implements PersistentStore {
 
             RowIterator it = rowIterator();
 
-            while (it.hasNext()) {
-                Row row = it.getNextRow();
+            while (it.next()) {
+                Row row = it.getCurrentRow();
 
                 ((RowAVL) row).clearNonPrimaryNodes();
 
@@ -346,8 +346,6 @@ public abstract class RowStoreAVL implements PersistentStore {
 
     public void resetAccessorKeys(Session session, Index[] keys) {
 
-        Index[] oldIndexList = indexList;
-
         searchCost = null;
 
         if (indexList.length == 0 || accessorList[0] == null) {
@@ -362,6 +360,7 @@ public abstract class RowStoreAVL implements PersistentStore {
             return;
         }
 
+        Index[]        oldIndexList = indexList;
         CachedObject[] oldAccessors = accessorList;
         int            limit        = indexList.length;
         int            diff         = keys.length - indexList.length;
@@ -535,8 +534,8 @@ public abstract class RowStoreAVL implements PersistentStore {
             Table       table = (Table) this.table;
             RowIterator it    = other.rowIterator();
 
-            while (it.hasNext()) {
-                Row      row      = it.getNextRow();
+            while (it.next()) {
+                Row      row      = it.getCurrentRow();
                 Object[] olddata  = row.getData();
                 Object[] data     = table.getEmptyRowData();
                 Object   oldvalue = null;
@@ -571,10 +570,10 @@ public abstract class RowStoreAVL implements PersistentStore {
             if (oldtype != null && oldtype.isLobType()) {
                 it = other.rowIterator();
 
-                while (it.hasNext()) {
-                    Row      row      = it.getNextRow();
+                while (it.next()) {
+                    Row      row      = it.getCurrentRow();
                     Object[] olddata  = row.getData();
-                    Object   oldvalue = olddata[colindex];
+                    LobData  oldvalue = (LobData) olddata[colindex];
 
                     if (oldvalue != null) {
                         session.sessionData.adjustLobUsageCount(oldvalue, -1);
@@ -585,10 +584,10 @@ public abstract class RowStoreAVL implements PersistentStore {
             if (newtype != null && newtype.isLobType()) {
                 it = rowIterator();
 
-                while (it.hasNext()) {
-                    Row      row   = it.getNextRow();
+                while (it.next()) {
+                    Row      row   = it.getCurrentRow();
                     Object[] data  = row.getData();
-                    Object   value = data[colindex];
+                    LobData  value = (LobData) data[colindex];
 
                     if (value != null) {
                         session.sessionData.adjustLobUsageCount(value, +1);
@@ -609,8 +608,8 @@ public abstract class RowStoreAVL implements PersistentStore {
 
             RowIterator it = table.rowIterator(this);
 
-            while (it.hasNext()) {
-                RowAVL row = (RowAVL) it.getNextRow();
+            while (it.next()) {
+                RowAVL row = (RowAVL) it.getCurrentRow();
 
                 row.getNode(index.getPosition()).delete();
                 index.insert(session, this, row);
@@ -635,9 +634,9 @@ public abstract class RowStoreAVL implements PersistentStore {
         RowIterator it       = primaryIndex.firstRow(this);
         int         position = oldIndex.getPosition() - 1;
 
-        while (it.hasNext()) {
-            Row     row      = it.getNextRow();
-            int     i        = position - 1;
+        while (it.next()) {
+            Row     row      = it.getCurrentRow();
+            int     i        = position;
             NodeAVL backnode = ((RowAVL) row).getNode(0);
 
             while (i-- > 0) {
@@ -662,8 +661,8 @@ public abstract class RowStoreAVL implements PersistentStore {
             HsqlException error    = null;
 
             try {
-                while (it.hasNext()) {
-                    Row row = it.getNextRow();
+                while (it.next()) {
+                    Row row = it.getCurrentRow();
 
                     ((RowAVL) row).insertNode(position);
 
@@ -686,8 +685,8 @@ public abstract class RowStoreAVL implements PersistentStore {
             // rowCount rows have been modified
             it = primaryIndex.firstRow(this);
 
-            for (int i = 0; i < rowCount; i++) {
-                Row     row      = it.getNextRow();
+            while (it.next()) {
+                Row     row      = it.getCurrentRow();
                 NodeAVL backnode = ((RowAVL) row).getNode(0);
                 int     j        = position;
 
@@ -718,6 +717,6 @@ public abstract class RowStoreAVL implements PersistentStore {
         IndexAVL idx  = (IndexAVL) indexList[0];
         NodeAVL  root = (NodeAVL) accessorList[0];
 
-        idx.unlinkNodes(root);
+        idx.unlinkNodes(this, root);
     }
 }
