@@ -57,7 +57,7 @@ import org.hsqldb.types.Types;
  * Class for reading the data for a database row in text table format.
  *
  * @author Bob Preston (sqlbob@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.3.5
  * @since 1.7.0
  */
 public class RowInputText extends RowInputBase implements RowInputInterface {
@@ -279,7 +279,13 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
             return null;
         }
 
-        return ValuePool.getInt(Integer.parseInt(s));
+        try {
+            int val = Integer.parseInt(s);
+
+            return ValuePool.getInt(val);
+        } catch (NumberFormatException e) {
+            throw Error.error(e, ErrorCode.X_22501, s);
+        }
     }
 
     protected Integer readInteger() {
@@ -296,7 +302,13 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
             return null;
         }
 
-        return ValuePool.getInt(Integer.parseInt(s));
+        try {
+            int val = Integer.parseInt(s);
+
+            return ValuePool.getInt(val);
+        } catch (NumberFormatException e) {
+            throw Error.error(e, ErrorCode.X_22501, s);
+        }
     }
 
     protected Long readBigint() {
@@ -313,7 +325,13 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
             return null;
         }
 
-        return ValuePool.getLong(Long.parseLong(s));
+        try {
+            long val = Long.parseLong(s);
+
+            return ValuePool.getLong(val);
+        } catch (NumberFormatException e) {
+            throw Error.error(e, ErrorCode.X_22501, s);
+        }
     }
 
     protected Double readReal() {
@@ -330,7 +348,11 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
             return null;
         }
 
-        return Double.valueOf(s);
+        try {
+            return Double.valueOf(s);
+        } catch (NumberFormatException e) {
+            throw Error.error(e, ErrorCode.X_22501, s);
+        }
     }
 
     protected BigDecimal readDecimal(Type type) {
@@ -347,7 +369,11 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
             return null;
         }
 
-        return new BigDecimal(s);
+        try {
+            return new BigDecimal(s);
+        } catch (NumberFormatException e) {
+            throw Error.error(e, ErrorCode.X_22501, s);
+        }
     }
 
     protected TimeData readTime(Type type) {
@@ -462,7 +488,7 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
             return null;
         }
 
-        BinaryData data = scanner.convertToBinary(s);
+        BinaryData data = scanner.convertToBinary(s, false);
 
         if (data.length(null) == 0) {
             return null;
@@ -484,6 +510,19 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
         return data;
     }
 
+    protected BinaryData readUUID() {
+
+        String s = readString();
+
+        if (s == null) {
+            return null;
+        }
+
+        BinaryData data = scanner.convertToBinary(s, true);
+
+        return data;
+    }
+
     protected BinaryData readBinary() {
 
         String s = readString();
@@ -492,7 +531,7 @@ public class RowInputText extends RowInputBase implements RowInputInterface {
             return null;
         }
 
-        BinaryData data = scanner.convertToBinary(s);
+        BinaryData data = scanner.convertToBinary(s, false);
 
         return data;
     }
