@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -112,14 +112,12 @@ public class RowOutputBinary extends RowOutputBase {
         super.writeData(row, types);
     }
 
-    public long scalePosition(long position) {
-        return (position + scale - 1) & (long) mask;
-    }
-
     public void setStorageSize(int size) {
         storageSize = size;
     }
 
+    public void setMode(int mode) {}
+
     public void writeEnd() {
 
         if (count > storageSize) {
@@ -165,7 +163,6 @@ public class RowOutputBinary extends RowOutputBase {
      *
      * @param  row - a database row
      * @return  size of byte array
-     * @exception  HsqlException When data is inconsistent
      */
     public int getSize(Row row) {
 
@@ -312,6 +309,10 @@ public class RowOutputBinary extends RowOutputBase {
         write(b, 0, 16);
     }
 
+    public void writeBytes(byte[] b) {
+        super.write(b);
+    }
+
     // fredt@users - comment - helper and conversion methods
     public void writeCharArray(char[] c) {
         writeInt(c.length);
