@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2016, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,7 @@ import org.hsqldb.types.Type;
 
 /**
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  */
 public class RowOutputTextLog extends RowOutputBase {
 
@@ -109,10 +109,6 @@ public class RowOutputTextLog extends RowOutputBase {
         this.writeBytes(o.toString());
     }
 
-    public long scalePosition(long position) {
-        return position;
-    }
-
     public void setStorageSize(int size) {}
 
     public void writeEnd() {}
@@ -256,6 +252,10 @@ public class RowOutputTextLog extends RowOutputBase {
         this.writeBytes(Long.toString(value));
     }
 
+    public void writeBytes(byte[] b) {
+        super.write(b);
+    }
+
     protected void writeTime(TimeData o, Type type) {
 
         write('\'');
@@ -307,6 +307,6 @@ public class RowOutputTextLog extends RowOutputBase {
     }
 
     public RowOutputInterface duplicate() {
-        throw Error.runtimeError(ErrorCode.U_S0500, "RowOutputText");
+        throw Error.runtimeError(ErrorCode.U_S0500, "RowOutputTextLog");
     }
 }
