@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -245,7 +245,7 @@ public class BinaryUUIDType extends BinaryType {
             return null;
         }
 
-        return ((BlobData) a).getBytes();
+        return  getJavaUUID((BinaryData) a);
     }
 
     Object castOrConvertToType(SessionInterface session, Object a,
@@ -521,29 +521,6 @@ public class BinaryUUIDType extends BinaryType {
         return new BinaryData(session, (BlobData) a, (BlobData) b);
     }
 
-    public long getLongColumnValue(Object value, int compareType) {
-
-        if (value == null) {
-            return Long.MIN_VALUE;
-        }
-
-        BinaryData binary    = (BinaryData) value;
-        byte[]     bytes     = binary.getBytes();
-        long       longValue = 0;
-
-        for (int i = 0; i < 8; i++) {
-            longValue |= (bytes[i] & 0x000000ff);
-
-            if (i == 7) {
-                break;
-            }
-
-            longValue <<= 8;
-        }
-
-        return longValue + Long.MIN_VALUE;
-    }
-
     public static BinaryData getBinary(long hi, long lo) {
         return new BinaryData(ArrayUtil.toByteArray(hi, lo), false);
     }
