@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,7 @@ import org.hsqldb.lib.StringConverter;
  * Type subclass for DATE, TIME and TIMESTAMP.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.0
+ * @version 2.4.1
  * @since 1.9.0
  */
 public final class DateTimeType extends DTIType {
@@ -305,6 +305,29 @@ public final class DateTimeType extends DTIType {
             case Types.SQL_TIMESTAMP_WITH_TIME_ZONE :
                 return true;
 
+            case Types.SQL_DATE :
+            case Types.SQL_TIME :
+            case Types.SQL_TIME_WITH_TIME_ZONE :
+                return false;
+
+            default :
+                throw Error.runtimeError(ErrorCode.U_S0500, "DateTimeType");
+        }
+    }
+
+    public boolean isTimeType() {
+
+        switch (typeCode) {
+
+            case Types.SQL_TIMESTAMP :
+            case Types.SQL_TIMESTAMP_WITH_TIME_ZONE :
+            case Types.SQL_DATE :
+                return false;
+
+            case Types.SQL_TIME :
+            case Types.SQL_TIME_WITH_TIME_ZONE :
+                return true;
+
             default :
                 throw Error.runtimeError(ErrorCode.U_S0500, "DateTimeType");
         }
@@ -995,53 +1018,54 @@ public final class DateTimeType extends DTIType {
             cal.clear();
 
             cal.set(year, month, day);
-            long milis = cal.getTimeInMillis();
-            return new TimestampData(milis, 0, zoneSeconds);
+            long seconds = cal.getTimeInMillis() / 1000;
+            return new TimestampData(seconds, 0, zoneSeconds);
         }
 
         return null;
     }
 
     TimeData convertJavaTimeObject(SessionInterface session, Object a) {
+        int secondsInDay = 24 * 3600;
         if (a instanceof java.time.OffsetTime) {
             java.time.OffsetTime odt = (java.time.OffsetTime) a;
+
             int zoneSeconds = 0;
 
             int hour = odt.getHour();
             int minute = odt.getMinute();
             int second = odt.getSecond();
-            int nanos = odt.getNano();
-            nanos = DateTimeType.normaliseFraction(nanos, scale);
+            int fraction = odt.getNano();
+            fraction = DateTimeType.normaliseFraction(fraction, scale);
 
-            if(withTimeZone) {
+            if (withTimeZone) {
                 zoneSeconds = odt.get(java.time.temporal.ChronoField.OFFSET_SECONDS);
             }
 
-            Calendar cal = session.getCalendarGMT();
-            cal.clear();
-            cal.set(1970, 1, 1, hour, minute, second);
-            int seconds = (int) cal.getTimeInMillis() / 1000;
-            return new TimeData(seconds, nanos, zoneSeconds);
+            int seconds = hour * 3600 + minute * 60 + second - zoneSeconds;
+
+            if (seconds < 0) {
+                seconds += secondsInDay;
+            } else if (seconds >=secondsInDay) {
+                seconds -= secondsInDay;
+            }
+
+            return new TimeData(seconds, fraction, zoneSeconds);
 
         } else if (a instanceof java.time.LocalTime) {
             java.time.LocalTime odt = (java.time.LocalTime) a;
+            long nanos = odt.toNanoOfDay();
+            int seconds = (int)(nanos / 1_000_000_000);
+            int fraction = (int)(nanos % 1_000_000_000);
+            fraction = DateTimeType.normaliseFraction(fraction, scale);
+
             int zoneSeconds = 0;
 
-            int hour = odt.getHour();
-            int minute = odt.getMinute();
-            int second = odt.getSecond();
-            int nanos = odt.getNano();
-            nanos = DateTimeType.normaliseFraction(nanos, scale);
-
-            if(withTimeZone) {
+            if (withTimeZone) {
                 zoneSeconds = session.getZoneSeconds();
             }
 
-            Calendar cal = session.getCalendarGMT();
-            cal.clear();
-            cal.set(1970, 1, 1, hour, minute, second);
-            int seconds = (int) cal.getTimeInMillis() / 1000;
-            return new TimeData(seconds, nanos, zoneSeconds);
+            return new TimeData(seconds, fraction, zoneSeconds);
         }
 
         return null;
