@@ -47,7 +47,7 @@ import org.hsqldb.map.ValuePool;
  * Type subclass for all NUMBER types.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
+ * @version 2.3.5
  * @since 1.9.0
  */
 public final class NumberType extends Type {
@@ -731,7 +731,8 @@ public final class NumberType extends Type {
                 } else if (b instanceof Double) {
                     BigDecimal ad =
                         BigDecimal.valueOf(((Number) a).longValue());
-                    BigDecimal bd = BigDecimal.valueOf(((Double) b).doubleValue());
+                    BigDecimal bd =
+                        BigDecimal.valueOf(((Double) b).doubleValue());
 
                     return ad.compareTo(bd);
                 } else if (b instanceof BigDecimal) {
@@ -899,6 +900,8 @@ public final class NumberType extends Type {
 
                     break;
                 }
+
+            // fall through
             default :
                 throw Error.error(ErrorCode.X_42561);
         }
@@ -1356,6 +1359,8 @@ public final class NumberType extends Type {
                         || otherType.typeCode == Types.SQL_DOUBLE) {
                     return 0;
                 }
+
+            // fall through
             default :
         }
 
@@ -1364,46 +1369,52 @@ public final class NumberType extends Type {
 
     public int compareToTypeRange(Object o) {
 
-        boolean isComparable;
-
-        if (o instanceof Integer || o instanceof Long) {
-            isComparable = true;
-        } else if (o instanceof BigDecimal) {
-            int compare = compareToLongLimits((BigDecimal) o);
-
-            if (compare != 0) {
-                return compare;
-            }
-
-            isComparable = true;
-        } else {
-            isComparable = false;
-        }
-
-        if (isComparable) {
+        if (o instanceof Integer || o instanceof Long
+                || o instanceof BigDecimal) {
             long temp = ((Number) o).longValue();
             int  min;
             int  max;
+            int  result;
 
             switch (typeCode) {
 
                 case Types.TINYINT :
+                    result = compareBigDecimalToLongLimits(o);
+
+                    if (result != 0) {
+                        return result;
+                    }
+
                     min = Byte.MIN_VALUE;
                     max = Byte.MAX_VALUE;
                     break;
 
                 case Types.SQL_SMALLINT :
+                    result = compareBigDecimalToLongLimits(o);
+
+                    if (result != 0) {
+                        return result;
+                    }
+
                     min = Short.MIN_VALUE;
                     max = Short.MAX_VALUE;
                     break;
 
                 case Types.SQL_INTEGER :
+                    result = compareBigDecimalToLongLimits(o);
+
+                    if (result != 0) {
+                        return result;
+                    }
+
                     min = Integer.MIN_VALUE;
                     max = Integer.MAX_VALUE;
                     break;
 
                 case Types.SQL_BIGINT :
-                    return 0;
+                    result = compareBigDecimalToLongLimits(o);
+
+                    return result;
 
                 case Types.SQL_DECIMAL :
                 case Types.SQL_NUMERIC : {
@@ -1817,35 +1828,7 @@ public final class NumberType extends Type {
     }
 
     public boolean isNegative(Object a) {
-
-        if (a == null) {
-            return false;
-        }
-
-        switch (typeCode) {
-
-            case Types.SQL_REAL :
-            case Types.SQL_FLOAT :
-            case Types.SQL_DOUBLE : {
-                double ad = ((Number) a).doubleValue();
-
-                return ad < 0;
-            }
-            case Types.SQL_NUMERIC :
-            case Types.SQL_DECIMAL :
-                return ((BigDecimal) a).signum() < 0;
-
-            case Types.TINYINT :
-            case Types.SQL_SMALLINT :
-            case Types.SQL_INTEGER :
-                return ((Number) a).intValue() < 0;
-
-            case Types.SQL_BIGINT :
-                return ((Number) a).longValue() < 0;
-
-            default :
-                throw Error.runtimeError(ErrorCode.U_S0500, "NumberType");
-        }
+        return compareToZero(a) < 0;
     }
 
     public int compareToZero(Object a) {
@@ -1912,22 +1895,33 @@ public final class NumberType extends Type {
         return value.movePointRight(scale).longValue();
     }
 
-    public static int compareToLongLimits(BigDecimal result) {
+    public static int compareBigDecimalToLongLimits(Object value) {
 
-        if (NumberType.MIN_LONG.compareTo(result) > 0) {
+        if (value instanceof BigDecimal) {
+            int compare = compareToLongLimits((BigDecimal) value);
+
+            return compare;
+        }
+
+        return 0;
+    }
+
+    public static int compareToLongLimits(BigDecimal value) {
+
+        if (NumberType.MIN_LONG.compareTo(value) > 0) {
             return -1;
-        } else if (NumberType.MAX_LONG.compareTo(result) < 0) {
+        } else if (NumberType.MAX_LONG.compareTo(value) < 0) {
             return 1;
         }
 
         return 0;
     }
 
-    public static int compareToLongLimits(BigInteger result) {
+    public static int compareToLongLimits(BigInteger value) {
 
-        if (NumberType.MIN_LONG_BI.compareTo(result) > 0) {
+        if (NumberType.MIN_LONG_BI.compareTo(value) > 0) {
             return -1;
-        } else if (NumberType.MAX_LONG_BI.compareTo(result) < 0) {
+        } else if (NumberType.MAX_LONG_BI.compareTo(value) < 0) {
             return 1;
         }
 
