@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2017, The HSQL Development Group
+/* Copyright (c) 2001-2018, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@ import org.hsqldb.rights.Grantee;
  * Base class for type objects.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.5
+ * @version 2.4.1
  * @since 1.9.0
  */
 public abstract class Type implements SchemaObject, Cloneable {
@@ -421,6 +421,10 @@ public abstract class Type implements SchemaObject, Cloneable {
         return false;
     }
 
+    public boolean isTimeType() {
+        return false;
+    }
+
     public boolean isIntervalType() {
         return false;
     }
@@ -648,8 +652,8 @@ public abstract class Type implements SchemaObject, Cloneable {
     // character types
     public static final CharacterType SQL_CHAR =
         new CharacterType(Types.SQL_CHAR, 1);
-    public static final CharacterType SQL_CHAR_16 =
-        new CharacterType(Types.SQL_CHAR, 16);
+    public static final CharacterType SQL_CHAR_UUID =
+        new CharacterType(Types.SQL_CHAR, 36);
     public static final CharacterType SQL_CHAR_DEFAULT =
         new CharacterType(Types.SQL_CHAR, CharacterType.defaultCharPrecision);
     public static final CharacterType SQL_VARCHAR =
@@ -680,7 +684,7 @@ public abstract class Type implements SchemaObject, Cloneable {
         new BinaryType(Types.SQL_VARBINARY, 32 * 1024);
     public static final BlobType SQL_BLOB =
         new BlobType(BlobType.defaultBlobSize);
-    public static final BinaryType SQL_GUID = new BinaryUUIDType();
+    public static final BinaryUUIDType SQL_GUID = new BinaryUUIDType();
 
     // other type
     public static final OtherType OTHER = OtherType.getOtherType();
@@ -886,6 +890,9 @@ public abstract class Type implements SchemaObject, Cloneable {
             case Types.SQL_VARBINARY :
                 return SQL_VARBINARY_DEFAULT;
 
+            case Types.SQL_GUID :
+                return SQL_GUID;
+
             case Types.SQL_BLOB :
                 return SQL_BLOB;
 
